/* Skriptovaci subor linkera pre pamat RAM */

/*
// <h> Konfiguracia pamate
//   <h> Program (Code) (read only - len na citanie)
//     <o>  Start <0x0-0xFFFFFFFF>
//     <o1> Size  <0x0-0xFFFFFFFF>
//   </h>
//   <h> Udaje (Data) (read/write - citanie/zapis)
//     <o2> Start <0x0-0xFFFFFFFF>
//     <o3> Size  <0x0-0xFFFFFFFF>
//   </h>
//   <h> Vrchol zasobnika (read/write - citanie/zapis)
//     <o4> STACK <0x0-0xFFFFFFFF>
//   </h>
// </h>
*/

/* Definicia pamati */
MEMORY
{
  CODE (rx) : ORIGIN = 0x00000000, LENGTH = 0x00003000
  DATA (rw) : ORIGIN = 0x00003000, LENGTH = 0x00001000
  STACK (rw) : ORIGIN = 0x00004000,LENGTH = 0x00000000
}


/* Definicia sekcii */

SECTIONS
{
  /* prvou sekciou je .text, ktora je pouzita pre program */
  . = 0x0000000;
  .text : { *cstartup.o (.text) }>CODE =0
  .text :
  {
    *(.text)                   /* zvysny program */

    *(.glue_7t) *(.glue_7)

  } >CODE =0

  . = ALIGN(4);               /* zarovnanie na hranicu 32 bitov */

  /* sekcia .rodata je pouzita pre udaje len na citanie (konstanty) */

  .rodata :
  {
    *(.rodata)
  } >CODE

  . = ALIGN(4);

  _etext = . ;
  PROVIDE (etext = .);

  /* sekcia .data je pre inicializovane udaje */

  .data : AT (_etext)
  {
    _data = . ;
    *(.data)
    SORT(CONSTRUCTORS)
  } >DATA
  . = ALIGN(4);

  _edata = . ;
   PROVIDE (edata = .);

  /* sekcia .bss je pre neinicializovane udaje */

  .bss :
  {
    __bss_start = . ;
    __bss_start__ = . ;
    *(.bss)
    *(COMMON)
  } 
  . = ALIGN(4);
  __bss_end__ = . ;
  __bss_end__ = . ;
  _end = .;
  PROVIDE (end = .);

    . = ALIGN(4);
   .int_data :  
   { 
   *(.internal_ram_top) 
   }> STACK 


  /* Sekcie pre debugovanie */
  .stab          0 : { *(.stab) }
  .stabstr       0 : { *(.stabstr) }
  .stab.excl     0 : { *(.stab.excl) }
  .stab.exclstr  0 : { *(.stab.exclstr) }
  .stab.index    0 : { *(.stab.index) }
  .stab.indexstr 0 : { *(.stab.indexstr) }
  .comment       0 : { *(.comment) }
  /* DWARF debugovacie sekcie.
     Symboly v debugovacich sekciach DWARF su relativne vzhladom
     na zaciatok sekcie, takze zacinaju na 0. */
  /* DWARF 1 */
  .debug          0 : { *(.debug) }
  .line           0 : { *(.line) }
  /* Rozsirenia GNU DWARF 1 */
  .debug_srcinfo  0 : { *(.debug_srcinfo) }
  .debug_sfnames  0 : { *(.debug_sfnames) }
  /* DWARF 1.1 a DWARF 2 */
  .debug_aranges  0 : { *(.debug_aranges) }
  .debug_pubnames 0 : { *(.debug_pubnames) }
  /* DWARF 2 */
  .debug_info     0 : { *(.debug_info .gnu.linkonce.wi.*) }
  .debug_abbrev   0 : { *(.debug_abbrev) }
  .debug_line     0 : { *(.debug_line) }
  .debug_frame    0 : { *(.debug_frame) }
  .debug_str      0 : { *(.debug_str) }
  .debug_loc      0 : { *(.debug_loc) }
  .debug_macinfo  0 : { *(.debug_macinfo) }
  /* rozsirenia SGI/MIPS DWARF 2 */
  .debug_weaknames 0 : { *(.debug_weaknames) }
  .debug_funcnames 0 : { *(.debug_funcnames) }
  .debug_typenames 0 : { *(.debug_typenames) }
  .debug_varnames  0 : { *(.debug_varnames) }
}
